@@ -598,6 +598,17 @@ class Bundler(object):
                                 property=required, name=schema_name
                             )
                         )
+                    if "x-status" in value["properties"][required].keys():
+                        if (
+                            value["properties"][required]["x-status"]["status"]
+                            == "deprecated"
+                        ):
+                            raise Exception(
+                                "Property {property} within schema {name} have "
+                                "both required as well as deprecated status".format(
+                                    property=required, name=schema_name
+                                )
+                            )
 
     def _resolve_x_pattern(self, pattern_extension):
         """Find all instances of pattern_extension in the openapi content
@@ -860,8 +871,17 @@ class Bundler(object):
             elif property_name == "values":
                 schema["default"] = [schema["default"]]
         if format is not None:
+            # TODO: fix this
+            # if property_name == "values":
+            #     schema["items"]["format"] = format
+            # else:
             schema["format"] = format
         if "length" in xpattern:
+            # TODO: fix this
+            # if property_name == "values":
+            #     schema["items"]["minimum"] = 0
+            #     schema["items"]["maximum"] = 2 ** int(xpattern["length"]) - 1
+            # else:
             schema["minimum"] = 0
             schema["maximum"] = 2 ** int(xpattern["length"]) - 1
 
@@ -921,47 +941,48 @@ class Bundler(object):
                     del content[pieces[-1]]
 
     def _resolve_x_status(self):
-        """Find all instances of x-constraint in the openapi content
-        and merge the x-constraint content into the parent object description
+        """Find all instances of x-status in the openapi content
+        and merge the x-status content into the parent object description
         """
         import jsonpath_ng
 
+        valid_statuses = ["deprecated", "under_review"]
         for xstatus in self._get_parser("$..x-status").find(self._content):
-            # TODO: restore behavior
-            # if xstatus.value.get("status") == "current":
-            #     continue
-            if xstatus.value == "current":
-                continue
+            status = xstatus.value.get("status")
 
-            # TODO: restore behavior
-            # assert (
-            #     xstatus.value.get("additional_information") is not None
-            # ), "attribute additional_info can't be " "None for %s" % (
-            #     str(xstatus.full_path)
-            # )
+            if status is not None:
+                status = status.replace("-", "_")
 
-            print("resolving %s..." % (str(xstatus.full_path)))
-            parent_schema_object = jsonpath_ng.Parent().find(xstatus)[0].value
+            if status not in valid_statuses:
+                raise Exception(
+                    "Invalid value for x-status.status={} provided; Valid values are {}".format(
+                        status, valid_statuses
+                    )
+                )
 
-            if "description" not in parent_schema_object:
-                parent_schema_object["description"] = "TBD"
-            parent_schema_object[
-                "description"
-            ] = "Status: {status}\n{description}".format(
-                status=xstatus.value,
-                description=parent_schema_object["description"],
-            )
+            print("resolving {} ...".format(xstatus.full_path))
+            parent = jsonpath_ng.Parent().find(xstatus)[0]
+            parent_schema = parent.value
 
-            # TODO: restore behavior
-            # if "description" not in parent_schema_object:
-            #     parent_schema_object["description"] = "TBD"
-            # parent_schema_object[
-            #     "description"
-            # ] = "Status: {status}\n{add_info}\n{description}".format(
-            #     status=xstatus.value.get("status"),
-            #     add_info=xstatus.value.get("additional_information", ""),
-            #     description=parent_schema_object["description"],
-            # )
+            info = xstatus.value.get("information")
+            if info is None or len(info) == 0:
+                info = xstatus.value["information"] = "Information TBD"
+                print(
+                    "[WARNING]: {}.x-status.information missing".format(
+                        parent.full_path
+                    )
+                )
+
+            if status == "deprecated":
+                status_msg = "Deprecated: {}".format(info)
+            elif status == "under_review":
+                status_msg = "Under Review: {}".format(info)
+
+            desc = parent_schema.get("description")
+            if desc is None or len(desc) == 0:
+                desc = "Description TBD"
+
+            parent_schema["description"] = "{}\n\n{}".format(status_msg, desc)
 
     def _resolve_x_unique(self):
         """validate the x-unique field and make sure it is [global]"""
