@@ -403,10 +403,12 @@ class OpenApiValidator(object):
         except Exception:
             return False
 
-    def validate_integer(self, value, min, max):
+    def validate_integer(self, value, min, max, type_format=None):
         if value is None or not isinstance(value, int):
             return False
-        if value < 0:
+        if type_format == "uint32" and value < 0:
+            return False
+        if type_format == "uint64" and value < 0:
             return False
         if min is not None and value < min:
             return False
@@ -476,8 +478,11 @@ class OpenApiValidator(object):
             list: "list",
             "int64": "integer",
             "int32": "integer",
+            "uint64": "integer",
+            "uint32": "integer",
             "double": "float",
         }
+        type_format = type_
         if type_ in type_map:
             type_ = type_map[type_]
         if itemtype is not None and itemtype in type_map:
@@ -500,7 +505,7 @@ class OpenApiValidator(object):
             )
             verdict = False
         elif type_ == "integer":
-            verdict = v_obj(value, min, max)
+            verdict = v_obj(value, min, max, type_format)
             if verdict is True:
                 return
             min_max = ""
@@ -617,6 +622,7 @@ class OpenApiObject(OpenApiBase, OpenApiValidator):
     _DEFAULTS = {}
     _TYPES = {}
     _REQUIRED = []
+    _STATUS = {}
 
     def __init__(self, parent=None, choice=None):
         super(OpenApiObject, self).__init__()
@@ -711,6 +717,7 @@ class OpenApiObject(OpenApiBase, OpenApiValidator):
     def _encode(self):
         """Helper method for serialization"""
         output = {}
+        self._raise_status_warnings(self, None)
         self._validate_required()
         for key, value in self._properties.items():
             self._validate_types(key, value)
@@ -719,22 +726,30 @@ class OpenApiObject(OpenApiBase, OpenApiValidator):
             # self._validate_constraint(key, value, True)
             if isinstance(value, (OpenApiObject, OpenApiIter)):
                 output[key] = value._encode()
+                if isinstance(value, OpenApiObject):
+                    self._raise_status_warnings(key, value)
             elif value is not None:
-                if self._TYPES.get(key, {}).get("format", "") == "int64":
+                if (
+                    self._TYPES.get(key, {}).get("format", "") == "int64"
+                    or self._TYPES.get(key, {}).get("format", "") == "uint64"
+                ):
                     value = str(value)
-                elif self._TYPES.get(key, {}).get("itemformat", "") == "int64":
+                elif (
+                    self._TYPES.get(key, {}).get("itemformat", "") == "int64"
+                    or self._TYPES.get(key, {}).get("itemformat", "")
+                    == "uint64"
+                ):
                     value = [str(v) for v in value]
                 output[key] = value
-                # TODO: restore behavior
-                # OpenApiStatus.warn(
-                #     "{}.{}".format(type(self).__name__, key), self
-                # )
+                self._raise_status_warnings(key, value)
         return output
 
     def _decode(self, obj):
         dtypes = [list, str, int, float, bool]
+        self._raise_status_warnings(self, None)
         for property_name, property_value in obj.items():
             if property_name in self._TYPES:
+                ignore_warnings = False
                 if isinstance(property_value, dict):
                     child = self._get_child_class(property_name)
                     if (
@@ -759,6 +774,7 @@ class OpenApiObject(OpenApiBase, OpenApiValidator):
                         item = child[1]()._decode(item)
                         openapi_list._items.append(item)
                     property_value = openapi_list
+                    ignore_warnings = True
                 elif (
                     property_name in self._DEFAULTS and property_value is None
                 ):
@@ -768,10 +784,15 @@ class OpenApiObject(OpenApiBase, OpenApiValidator):
                         property_value = self._DEFAULTS[property_name]
                 self._set_choice(property_name)
                 # convert int64(will be string on wire) to to int
-                if self._TYPES[property_name].get("format", "") == "int64":
+                if (
+                    self._TYPES[property_name].get("format", "") == "int64"
+                    or self._TYPES[property_name].get("format", "") == "uint64"
+                ):
                     property_value = int(property_value)
                 elif (
                     self._TYPES[property_name].get("itemformat", "") == "int64"
+                    or self._TYPES[property_name].get("itemformat", "")
+                    == "uint64"
                 ):
                     property_value = [int(v) for v in property_value]
                 self._properties[property_name] = property_value
@@ -779,6 +800,8 @@ class OpenApiObject(OpenApiBase, OpenApiValidator):
                 # OpenApiStatus.warn(
                 #     "{}.{}".format(type(self).__name__, property_name), self
                 # )
+                if not ignore_warnings:
+                    self._raise_status_warnings(property_name, property_value)
             self._validate_types(property_name, property_value)
             # TODO: restore behavior
             # self._validate_unique_and_name(property_name, property_value, True)
@@ -938,6 +961,21 @@ class OpenApiObject(OpenApiBase, OpenApiValidator):
             return self._properties.pop(name)
         return None
 
+    def _raise_status_warnings(self, property_name, property_value):
+        if len(self._STATUS) > 0:
+
+            if isinstance(property_name, OpenApiObject):
+                if "self" in self._STATUS and property_value is None:
+                    print("[WARNING]: %s" % self._STATUS["self"])
+
+                return
+
+            enum_key = "%s.%s" % (property_name, property_value)
+            if property_name in self._STATUS:
+                print("[WARNING]: %s" % self._STATUS[property_name])
+            elif enum_key in self._STATUS:
+                print("[WARNING]: %s" % self._STATUS[enum_key])
+
 
 class OpenApiIter(OpenApiBase):
     """Container class for OpenApiObject
